@@ -4,4 +4,4 @@ $VAR1 = { 'start' => { 'file'  => 'start.pl',
                        'name'  => 'Lindner',
           },
 };
-$m_hrActions = $VAR1;
+$m_sActions = $VAR1;
